@@ -407,14 +407,26 @@ class PluginConfigService(Protocol):
     ) -> None: ...
 
 
-# system manager
-class SystemManager(Protocol):  # todo: add methods
-    pass
+# manager todo: improve typing
+class SystemManager(Protocol):
+    def on(self, event: str, listener: Callable) -> "SystemManager": ...
+    def once(self, event: str, listener: Callable) -> "SystemManager": ...
+    def remove_listener(self, event: str, listener: Callable) -> "SystemManager": ...
+    def remove_all_listeners(self, event: str) -> "SystemManager": ...
 
 
-# plugins manager
 class PluginsManager(Protocol):  # todo: add methods
-    pass
+    def on(self, event: str, listener: Callable) -> "PluginsManager": ...
+    def once(self, event: str, listener: Callable) -> "PluginsManager": ...
+    def remove_listener(self, event: str, listener: Callable) -> "PluginsManager": ...
+    def remove_all_listeners(self, event: str) -> "PluginsManager": ...
+
+
+class DeviceManager(Protocol):  # todo: add methods
+    def on(self, event: str, listener: Callable) -> "DeviceManager": ...
+    def once(self, event: str, listener: Callable) -> "DeviceManager": ...
+    def remove_listener(self, event: str, listener: Callable) -> "DeviceManager": ...
+    def remove_all_listeners(self, event: str) -> "DeviceManager": ...
 
 
 # plugin api
@@ -427,7 +439,7 @@ class PluginAPI(Protocol):
     config_file: str
     config_service: PluginConfigService
     storage_controller: StorageController
-    device_manager: Any  # todo: replace Any with DeviceManager
+    device_manager: DeviceManager
     system_manager: SystemManager
     plugins_manager: PluginsManager
 
